# Table of Contents

- [tags-and-custom-fields](<./tags-and-custom-fields.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Using Tags and Custom Fields](<./Using-Tags-and-Custom-Fields.md>)
  - [Overview](<./Using-Tags-and-Custom-Fields/Overview.md>)
  - [When to Use Tags](<./Using-Tags-and-Custom-Fields/When-to-Use-Tags.md>)
  - [When to Use Custom Attributes](<./Using-Tags-and-Custom-Fields/When-to-Use-Custom-Attributes.md>)
  - [Single- and Multiple-Select Fields and Tag Groups](<./Using-Tags-and-Custom-Fields/Single--and-Multiple-Select-Fields-and-Tag-Groups.md>)
  - [Was this page helpful?](<./Using-Tags-and-Custom-Fields/Was-this-page-helpful.md>)
